bayespy.inference.vmp.nodes.constant.Constant.broadcasting_multiplier
=====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.constant

.. automethod:: Constant.broadcasting_multiplier